/// <reference types="node" />
import express from "express";
import type { Request as ExpressRequest, Response as ExpressResponse, NextFunction as ExpressNextFunction } from "express";
import type { Handler, Document, Context as OpenAPIBackendContext } from "openapi-backend";
import type { SimulationStore, ExtendSimulationActionsInput, ExtendSimulationActions, ExtendSimulationSelectorsInput, ExtendSimulationSelectors } from "./store/index";
import type { ExtendSimulationSchemaInput, ExtendSimulationSchema, SimulationRoute } from "./store/schema";
import type { RecursivePartial } from "./store/types";
type SimulationHandlerFunctions = (context: OpenAPIBackendContext, request: ExpressRequest, response: ExpressResponse, next: ExpressNextFunction, routeMetadata: SimulationRoute) => void;
export type SimulationHandlers = Record<string, SimulationHandlerFunctions>;
export type { ExtendSimulationActions, ExtendSimulationSelectors, ExtendSimulationSchema, SimulationStore, Document, };
export type { AnyState } from "starfx";
export declare function createFoundationSimulationServer<ExtendedSimulationSchema, ExtendedSimulationActions, ExtendedSimulationSelectors>({ port, serveJsonFiles, openapi, extendStore, extendRouter, }: {
    port: number;
    serveJsonFiles?: string;
    openapi?: {
        document: Document | (Document | RecursivePartial<Document>)[];
        handlers: (simulationStore: SimulationStore<ExtendedSimulationSchema, ExtendedSimulationActions, ExtendedSimulationSelectors>) => Record<string, Handler | Record<string, Handler>>;
        apiRoot?: string;
    }[];
    extendStore?: {
        schema: ExtendSimulationSchemaInput<ExtendedSimulationSchema>;
        actions: ExtendSimulationActionsInput<ExtendedSimulationActions, ExtendedSimulationSchema>;
        selectors: ExtendSimulationSelectorsInput<ExtendedSimulationSelectors, ExtendedSimulationSchema>;
        logs?: boolean;
    };
    extendRouter?(router: express.Router, simulationStore: SimulationStore<ExtendedSimulationSchema, ExtendedSimulationActions, ExtendedSimulationSelectors>): void;
}): () => {
    listen: (portOverride?: number, callback?: () => void) => Promise<{
        server: import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse>;
        simulationStore: {
            store: import("starfx").FxStore<{
                cache: (n: string) => import("starfx").TableOutput<{}, import("starfx").AnyState, {}>;
                loaders: (name: string) => import("starfx").LoaderOutput<M, import("starfx").AnyState>;
                simulationLogs: (n: string) => import("starfx").TableOutput<import("./store/schema").SimulationLog, import("starfx").AnyState, import("./store/schema").SimulationLog | undefined>;
                simulationRoutes: (n: string) => import("starfx").TableOutput<SimulationRoute, import("starfx").AnyState, SimulationRoute>;
            } & ExtendedSimulationSchema extends infer T extends import("starfx").FxMap ? { [key in keyof T]: ReturnType<({
                cache: (n: string) => import("starfx").TableOutput<{}, import("starfx").AnyState, {}>;
                loaders: (name: string) => import("starfx").LoaderOutput<M, import("starfx").AnyState>;
                simulationLogs: (n: string) => import("starfx").TableOutput<import("./store/schema").SimulationLog, import("starfx").AnyState, import("./store/schema").SimulationLog | undefined>;
                simulationRoutes: (n: string) => import("starfx").TableOutput<SimulationRoute, import("starfx").AnyState, SimulationRoute>;
            } & ExtendedSimulationSchema)[key]>["initialState"]; } : never>;
            schema: import("starfx").FxSchema<{
                cache: (n: string) => import("starfx").TableOutput<{}, import("starfx").AnyState, {}>;
                loaders: (name: string) => import("starfx").LoaderOutput<M, import("starfx").AnyState>;
                simulationLogs: (n: string) => import("starfx").TableOutput<import("./store/schema").SimulationLog, import("starfx").AnyState, import("./store/schema").SimulationLog | undefined>;
                simulationRoutes: (n: string) => import("starfx").TableOutput<SimulationRoute, import("starfx").AnyState, SimulationRoute>;
            } & ExtendedSimulationSchema extends infer T_1 extends import("starfx").FxMap ? { [key in keyof T_1]: ReturnType<({
                cache: (n: string) => import("starfx").TableOutput<{}, import("starfx").AnyState, {}>;
                loaders: (name: string) => import("starfx").LoaderOutput<M, import("starfx").AnyState>;
                simulationLogs: (n: string) => import("starfx").TableOutput<import("./store/schema").SimulationLog, import("starfx").AnyState, import("./store/schema").SimulationLog | undefined>;
                simulationRoutes: (n: string) => import("starfx").TableOutput<SimulationRoute, import("starfx").AnyState, SimulationRoute>;
            } & ExtendedSimulationSchema)[key]>["initialState"]; } : never, {
                cache: (n: string) => import("starfx").TableOutput<{}, import("starfx").AnyState, {}>;
                loaders: (name: string) => import("starfx").LoaderOutput<M, import("starfx").AnyState>;
                simulationLogs: (n: string) => import("starfx").TableOutput<import("./store/schema").SimulationLog, import("starfx").AnyState, import("./store/schema").SimulationLog | undefined>;
                simulationRoutes: (n: string) => import("starfx").TableOutput<SimulationRoute, import("starfx").AnyState, SimulationRoute>;
            } & ExtendedSimulationSchema>;
            actions: {
                simulationLog: import("starfx").CreateActionWithPayload<Omit<import("starfx").ThunkCtx<any>, "payload"> & import("starfx").Payload<{
                    method: string;
                    url: string;
                    query: Record<string, any>;
                    body: any;
                }>, {
                    method: string;
                    url: string;
                    query: Record<string, any>;
                    body: any;
                }, any>;
                batchUpdater: import("starfx").CreateActionWithPayload<Omit<import("starfx").ThunkCtx<any>, "payload"> & import("starfx").Payload<import("starfx").StoreUpdater<import("starfx").AnyState>[]>, import("starfx").StoreUpdater<import("starfx").AnyState>[], any>;
            } & ExtendedSimulationActions;
            selectors: ExtendedSimulationSelectors;
        };
        ensureClose: () => Promise<void>;
    }>;
};
export declare function startFoundationSimulationServer<ExtendedSimulationSchema, ExtendedSimulationActions, ExtendedSimulationSelectors>(arg: Parameters<typeof createFoundationSimulationServer<ExtendedSimulationSchema, ExtendedSimulationActions, ExtendedSimulationSelectors>>[0]): Promise<{
    server: import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse>;
    simulationStore: {
        store: import("starfx").FxStore<{
            cache: (n: string) => import("starfx").TableOutput<{}, import("starfx").AnyState, {}>;
            loaders: (name: string) => import("starfx").LoaderOutput<M, import("starfx").AnyState>;
            simulationLogs: (n: string) => import("starfx").TableOutput<import("./store/schema").SimulationLog, import("starfx").AnyState, import("./store/schema").SimulationLog | undefined>;
            simulationRoutes: (n: string) => import("starfx").TableOutput<SimulationRoute, import("starfx").AnyState, SimulationRoute>;
        } & ExtendedSimulationSchema extends infer T extends import("starfx").FxMap ? { [key in keyof T]: ReturnType<({
            cache: (n: string) => import("starfx").TableOutput<{}, import("starfx").AnyState, {}>;
            loaders: (name: string) => import("starfx").LoaderOutput<M, import("starfx").AnyState>;
            simulationLogs: (n: string) => import("starfx").TableOutput<import("./store/schema").SimulationLog, import("starfx").AnyState, import("./store/schema").SimulationLog | undefined>;
            simulationRoutes: (n: string) => import("starfx").TableOutput<SimulationRoute, import("starfx").AnyState, SimulationRoute>;
        } & ExtendedSimulationSchema)[key]>["initialState"]; } : never>;
        schema: import("starfx").FxSchema<{
            cache: (n: string) => import("starfx").TableOutput<{}, import("starfx").AnyState, {}>;
            loaders: (name: string) => import("starfx").LoaderOutput<M, import("starfx").AnyState>;
            simulationLogs: (n: string) => import("starfx").TableOutput<import("./store/schema").SimulationLog, import("starfx").AnyState, import("./store/schema").SimulationLog | undefined>;
            simulationRoutes: (n: string) => import("starfx").TableOutput<SimulationRoute, import("starfx").AnyState, SimulationRoute>;
        } & ExtendedSimulationSchema extends infer T_1 extends import("starfx").FxMap ? { [key in keyof T_1]: ReturnType<({
            cache: (n: string) => import("starfx").TableOutput<{}, import("starfx").AnyState, {}>;
            loaders: (name: string) => import("starfx").LoaderOutput<M, import("starfx").AnyState>;
            simulationLogs: (n: string) => import("starfx").TableOutput<import("./store/schema").SimulationLog, import("starfx").AnyState, import("./store/schema").SimulationLog | undefined>;
            simulationRoutes: (n: string) => import("starfx").TableOutput<SimulationRoute, import("starfx").AnyState, SimulationRoute>;
        } & ExtendedSimulationSchema)[key]>["initialState"]; } : never, {
            cache: (n: string) => import("starfx").TableOutput<{}, import("starfx").AnyState, {}>;
            loaders: (name: string) => import("starfx").LoaderOutput<M, import("starfx").AnyState>;
            simulationLogs: (n: string) => import("starfx").TableOutput<import("./store/schema").SimulationLog, import("starfx").AnyState, import("./store/schema").SimulationLog | undefined>;
            simulationRoutes: (n: string) => import("starfx").TableOutput<SimulationRoute, import("starfx").AnyState, SimulationRoute>;
        } & ExtendedSimulationSchema>;
        actions: {
            simulationLog: import("starfx").CreateActionWithPayload<Omit<import("starfx").ThunkCtx<any>, "payload"> & import("starfx").Payload<{
                method: string;
                url: string;
                query: Record<string, any>;
                body: any;
            }>, {
                method: string;
                url: string;
                query: Record<string, any>;
                body: any;
            }, any>;
            batchUpdater: import("starfx").CreateActionWithPayload<Omit<import("starfx").ThunkCtx<any>, "payload"> & import("starfx").Payload<import("starfx").StoreUpdater<import("starfx").AnyState>[]>, import("starfx").StoreUpdater<import("starfx").AnyState>[], any>;
        } & ExtendedSimulationActions;
        selectors: ExtendedSimulationSelectors;
    };
    ensureClose: () => Promise<void>;
}>;
//# sourceMappingURL=index.d.ts.map