"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSimulationStore = void 0;
const schema_1 = require("./schema");
const starfx_1 = require("starfx");
const starfx_2 = require("starfx");
function createSimulationStore({ actions: inputActions, selectors: inputSelectors, schema: inputSchema, logs = false, } = {
    schema: (() => ({})),
    actions: (() => ({})),
    selectors: (() => ({})),
    logs: false,
}) {
    const thunks = (0, starfx_2.createThunks)();
    // catch errors from task and logs them with extra info
    thunks.use(starfx_2.mdw.err);
    // where all the thunks get called in the middleware stack
    thunks.use(thunks.routes());
    let batchUpdater = thunks.create("update", function* (ctx, next) {
        yield* (0, starfx_2.updateStore)(ctx.payload);
        yield* next();
    });
    let simulationLog = thunks.create("simulationLog", function* (ctx, next) {
        const { method, url, query, body } = ctx.payload;
        const timestamp = Date.now();
        yield* schema.update(schema.simulationLogs.add({
            [timestamp]: {
                timestamp,
                level: "info",
                message: `${method} ${url}`,
                meta: { method, url, query, body },
            },
        }));
        yield* next();
    });
    let additionalTasks = [thunks.bootup];
    let [schema, schemaInitialState] = (0, schema_1.generateSchemaWithInputSlices)(inputSchema);
    let store = (0, starfx_1.createStore)({
        initialState: {
            ...schemaInitialState,
        },
    });
    let inputedActions = inputActions({ thunks, store, schema });
    let actions = {
        simulationLog,
        batchUpdater,
        ...inputedActions,
    };
    let tsks = [...additionalTasks];
    if (logs) {
        // log all actions dispatched
        tsks.push(function* logActions() {
            while (true) {
                let action = yield* (0, starfx_1.take)("*");
                console.dir(action, { depth: 5 });
            }
        });
    }
    store.run(function* () {
        let group = yield* (0, starfx_1.parallel)(tsks);
        yield* group;
    });
    let inputedSelectors = inputSelectors({ store, schema, createSelector: starfx_1.createSelector });
    return {
        store,
        schema,
        actions,
        selectors: inputedSelectors,
    };
}
exports.createSimulationStore = createSimulationStore;
//# sourceMappingURL=index.js.map